@@ -6,7 +6,7 @@ import sys
 import os
 import subprocess
 
-p = subprocess.Popen('find dist -name "site-packages"', shell=1,
+p = subprocess.Popen('find dist -name "site-packages" 2>/dev/null', shell=1,
     stdout=subprocess.PIPE).stdout
 sitepkgsdir = p.readline().strip('\n')
 os.environ['PYTHONPATH'] = os.path.join(os.getcwd(), sitepkgsdir)
@@ -23,7 +23,7 @@ try:
         cmd += (s + ' ')
     r = subprocess.call(cmd, shell=1)
     if r < 0:
-        print >>sys.stderr, 'child terminatd by signal', -r
+        print >>sys.stderr, 'child terminated by signal', -r
 except OSError, e:
     print >>sys.stderr, 'execution failed', e
 except KeyboardInterrupt:
