@@ -24,15 +24,13 @@
 import os
 import platform
 import random
+import locale
 from optparse import OptionParser, OptionGroup
 
 import clive as _clive
 from clive.config import ConfigParser
 try:
     import clive.urlgrabber as urlg
-except ImportError, err:
-    raise SystemExit('error: %s' % err)
-try:
     from clive.feedparser import feedparser as fparser
 except ImportError, err:
     raise SystemExit('error: %s' % err)
@@ -51,16 +49,19 @@ class Options:
 
     ## Constructor
     def __init__(self):
-        self._ver = '%s (%s; py/%s; urlg/%s; fparser/%s' % (
-            _clive.__version_str__,
-            '%s/%s' % (platform.system().lower(), \
-            platform.release().split('-',1)[0]),
-            platform.python_version(),
-            urlg.__version__,
-            fparser.__version__)
+        (lang, self._encoding) = locale.getdefaultlocale()
+        if not self._encoding:
+            self._encoding = 'iso-8859-1'
+        self._ver = 'clive %s %s  [%s]\n' \
+            'python/%s; urlgrabber/%s; feedparser/%s' % (
+            _clive.__version__, _clive.__date__.replace('-',''),
+            platform.system(), platform.python_version(),
+            urlg.__version__, fparser.__version__)
         if len(_clive.__newt_version__) > 0:
             self._ver += '; newt/%s' % _clive.__newt_version__
-        self._ver += ')'
+        self._ver += '\n%s/%s; locale=%s' % ( \
+            platform.system(), platform.release().split('-',1)[0],
+            self._encoding)
         self._warnings = []
 
     ## Parses options
@@ -70,23 +71,8 @@ class Options:
 
     ## Print some options to stdout
     def show(self, say):
-        onoff = ['off','yes']
-        reencode = self.opts.reencode_format
-        if not reencode: reencode = 'off'
-        play = self.opts.play_format
-        if not play: play = 'off'
-        say('%s\ncache:%s; paste:%s; play:%s; encode:%s; rate:%s; exist:%s' % (
-            self._ver,
-            (onoff[self.opts.enable_cache]),
-            (onoff[self.opts.enable_xclip_paste]),
-            play, reencode,
-            (['off','%.0fK/s' % (self.opts.http_throttle/1024)] \
-                [self.opts.http_throttle > 0]),
-            self.opts.output_exists.lower())
-        )
-
-        for w in self._warnings:
-            say(w)
+        say(self._ver.split('\n',1)[0])
+        for w in self._warnings: say(w)
 
     def _parse_opts(self):
         self._conf_parser = ConfigParser()
@@ -223,6 +209,36 @@ class Options:
                 'desc':'scan and select video links from source URLs',
                 'default':False,
             },
+            'enable_cache_browse':{
+                'group':p,
+                'l_opt':'--cache',
+                's_opt':'-c',
+                'action':'store_true',
+                'choices':None,
+                'metavar':None,
+                'desc':'browse and re-extract from cache',
+                'default':False,
+            },
+            'clear_cache':{
+                'group':p,
+                'l_opt':'--clear-cache',
+                's_opt':'-d',
+                'action':'store_true',
+                'choices':None,
+                'metavar':None,
+                'desc':'clear cache data from ~/.clive/cache',
+                'default':False,
+            },
+            'clear_last':{
+                'group':p,
+                'l_opt':'--clear-last',
+                's_opt':'-D',
+                'action':'store_true',
+                'choices':None,
+                'metavar':None,
+                'desc':'clear last batch data from ~/.clive/recall',
+                'default':False,
+            },
             # Output group
             'output_exists':{
                 'group':gout,
@@ -254,15 +270,15 @@ class Options:
                 'desc':'write videos to directory',
                 'default':confp.get_default('output_savedir'),
             },
-            'output_mask':{
+            'output_filter':{
                 'group':gout,
-                'l_opt':'--mask',
+                'l_opt':'--filter',
                 's_opt':'-m',
                 'action':'store',
                 'choices':None,
                 'metavar':'M',
-                'desc':'use mask for title filtering re.sub call',
-                'default':confp.get_default('output_mask'),
+                'desc':'filter title; either regexp (re.sub), "custom" or "no"',
+                'default':confp.get_default('output_filter'),
             },
             'output_format':{
                 'group':gout,
@@ -395,7 +411,7 @@ class Options:
                 'action':'store',
                 'choices':None,
                 'metavar':'PATH',
-                'desc':'path to xclip (must include "-o")',
+                'desc':'path to xclip',
                 'default':confp.get_default('xclip'),
             },
             'enable_xclip_paste':{
@@ -476,7 +492,6 @@ class Options:
                 self._warnings.append('warn: --ffmpeg unused, using --play=src')
 
         if self.opts.player:
-            ##if self.opts.player.find('%i') == -1:
             if '%i' not in self.opts.player:
                 if self.opts.play_format:
                     self._warnings.append('warn: --player missing "%i", ' +
@@ -489,7 +504,6 @@ class Options:
 
         if self.opts.ffmpeg:
             for s in ['%i','%o']:
-                ##if self.opts.ffmpeg.find(s) == -1:
                 if s not in self.opts.ffmpeg:
                     if self.opts.reencode_format:
                         self._warnings.append('warn: --ffmpeg missing "%s", ' \
@@ -506,6 +520,11 @@ class Options:
             if not self.opts.xclip:
                 self.opts.enable_xclip_paste = False
                 self._warnings.append('warn: --xclip unused, ignoring --paste')
+            else:                
+                if '-o' not in self.opts.xclip:
+                    self.opts.xclip += ' -o'
+                    self._warnings.append('warn: --xclip missing "-o", ' +
+                        'appending it')
 
         # Modify: cache
         if not _sqlite3_found:
@@ -535,6 +554,10 @@ class Options:
                 self._warnings.append('warn: --dmotion-user unused, ' +
                     'ignoring --dmotion-pass')
 
+        # Check for default locale settings which are used for string
+        # conversions.
+        setattr(self.opts, 'encoding', self._encoding) # Add artificially
+
         # Modify: Append "artificially" feed_url attribute to the options
         # The "feed_url" a sequence of RSS/Atom URLs from the command line
         # or the config file.
