@@ -21,6 +21,8 @@
 
 ## The classes that wrap the recall functionalities
 
+import os
+
 from clive.path import ConfigDir
 
 __all__ = ['Recall']
@@ -31,8 +33,14 @@ class Recall:
     ## Writes URL batch to the recall file
     def write(self, batch):
         f = open(ConfigDir().recallfile(), 'w')
-        for url in batch:
-            f.write('%s\n' % url)
+        for url in batch: f.write('%s\n' % url)
         f.close()
 
-
+    ## Clears data
+    def clear(self, say):
+        if os.path.exists(ConfigDir().recallfile()):
+            a = raw_input('> clear last batch, are you sure? (y/N): ')
+            if len(a) and a.lower()[0] == 'y':
+                os.remove(ConfigDir().recallfile())
+        else:
+            say('error: recall: nothing to clear')
